==> flyshare-0.0.18.tar.gz: flyshare-0.0.18/README.md <==
# Flyshare


## Getting Startted
### [Authentication](http://www.asiabigdata.org/registration/)

Get your free API key to start using the data collected from China stock.

You can find your API key on your [account settings page](http://www.asiabigdata.org/login/).

#### Authenticating your requests
The Flyshare is free but you must have a API key in order to download data. To get your own API key, you will need to create a free  account and set your API key.

After importing the Flyshare module, you can set your API key with the following command: 
```
flyshare.ApiConfig.api_key = "YOURAPIKEY"
```

### Free Data
Flyshare has a vast collection of free and open data collected from a variety of organizations: 
central banks, governments, multinational organizations and more. 


## Installation

To install pyfolio, run:

```bash
pip install flyshare
import flyshare 
```

## Usage

A good way to get started is to run the flyshare examples in
a [Jupyter notebook](http://jupyter.org/). To do this, you first want to
start a Jupyter notebook server:

```bash
jupyter notebook
```

From the notebook list page, navigate to the pyfolio examples directory
and open a notebook. Execute the code in a notebook cell by clicking on it
and hitting Shift+Enter.


## Questions?

If you find a bug, feel free to [open an issue](https://github.com/duanrb/flyshare/issues) in this repository.


For a list of core developers and outside collaborators, see [the GitHub contributors list](https://github.com/duanrb/flyshare/graphs/contributors)

==> flyshare-0.0.21.tar.gz: flyshare-0.0.21/README.md <==
# Flyshare


## Getting Startted
### [Authentication](http://www.asiabigdata.org/registration/)

Get your free API key to start using the data collected from stock markets like China, Hong Kong, USA, etc.

You can find your API key on your [account settings page](http://www.asiabigdata.org/login/).

#### Authenticating your requests
The Flyshare is free but you must have a API key in order to download data. To get your own API key, you will need to create a free  account and set your API key.

After importing the Flyshare module, you can set your API key with the following command: 
```
flyshare.ApiConfig.api_key = "YOURAPIKEY"
```

### Free Data
Flyshare has a vast collection of free and open data collected from a variety of organizations: 
central banks, governments, multinational organizations and more. 


## Installation

To install pyfolio, run:

```bash
pip install flyshare
import flyshare 
```

## Usage

A good way to get started is to run the [flyshare examples](tutorial) in
a [Jupyter notebook](http://jupyter.org/). To do this, you first want to
start a Jupyter notebook server:

```bash
jupyter notebook
```

From the notebook list page, navigate to the [examples directory](tutorial)
and open a notebook. Execute the code in a notebook cell by clicking on it
and hitting Shift+Enter.


## Questions?

If you find a bug, feel free to [open an issue](https://github.com/duanrb/flyshare/issues) in this repository.


For a list of core developers and outside collaborators, see [the GitHub contributors list](https://github.com/duanrb/flyshare/graphs/contributors)
